summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorEino-Ville Talvala <etalvala@google.com>2013-09-12 18:32:13 +0000
committerAndroid (Google) Code Review <android-gerrit@google.com>2013-09-12 18:32:13 +0000
commit7359406a91073a5ed586ec0b64c0508d8fda5729 (patch)
treec6be9b2123cae4c8c7fb56d4d995d5294c7d8375
parent0747b8cdde87301ea75a94536adc3f86f793d9b6 (diff)
parent23d4b2c087bd4286bf16bda83b6d9f72c5bb1718 (diff)
downloadandroid_system_media-7359406a91073a5ed586ec0b64c0508d8fda5729.tar.gz
android_system_media-7359406a91073a5ed586ec0b64c0508d8fda5729.tar.bz2
android_system_media-7359406a91073a5ed586ec0b64c0508d8fda5729.zip
Merge "Camera: Fix Java metadata generation bug" into klp-dev
-rw-r--r--camera/docs/metadata_helpers.py7
1 files changed, 3 insertions, 4 deletions
diff --git a/camera/docs/metadata_helpers.py b/camera/docs/metadata_helpers.py
index 51444bf5..e897ed01 100644
--- a/camera/docs/metadata_helpers.py
+++ b/camera/docs/metadata_helpers.py
@@ -156,18 +156,17 @@ def get_children_by_throwing_away_kind(node, member='entries'):
def get_children_by_filtering_kind(section, kind_name, member='entries'):
"""
Takes a section and yields the children of the kind under this section.
Args:
section: An instance of Section
kind_name: A name of the kind, i.e. 'dynamic' or 'static' or 'controls'
Returns:
An iterable over the children of the specified kind.
"""
-# TODO: test/use this function
- matched_kind = next((i for i in section.kinds if i.name == kind_name), None)
+ matched_kind = next((i for i in section.merged_kinds if i.name == kind_name), None)
if matched_kind:
return getattr(matched_kind, member)
@@ -156,18 +156,17 @@ def get_children_by_throwing_away_kind(node, member='entries'):
def get_children_by_filtering_kind(section, kind_name, member='entries'):
"""
- Takes a section and yields the children of the kind under this section.
+ Takes a section and yields the children of the merged kind under this section.
Args:
section: An instance of Section
@@ -156,18 +156,17 @@ def get_children_by_throwing_away_kind(node, member='entries'):
kind_name: A name of the kind, i.e. 'dynamic' or 'static' or 'controls'
Returns:
- An iterable over the children of the specified kind.
+ An iterable over the children of the specified merged kind.
"""